@@ -4,14 +4,7 @@ import shutil
 from os import makedirs
 from os.path import abspath, dirname, isdir
 from typing import Any
-
-try:
-    # Python 3
-    from urllib.request import urlopen
-except ImportError:
-    # Python 2
-    # noinspection PyUnresolvedReferences
-    from urllib2 import urlopen  # type: ignore[import,no-redef]
+from urllib.request import urlopen
 
 
 def _open(url: str) -> Any:
@@ -22,6 +15,13 @@ def _open(url: str) -> Any:
         return None
 
 
+def get_redirect(url: str) -> str | None:
+    req = _open(url)
+    if not req:
+        return None
+    return str(req.geturl())
+
+
 def raw(url: str, encoding: str = "utf-8") -> str | None:
     resp = _open(url)
     if not resp:
